@@ -357,7 +357,7 @@ fn write_only() {
 }
 
 #[test]
-fn inline_field() {
+fn inline_fields() {
     #[derive(Object)]
     struct Obj {
         /// Inner Obj
@@ -402,13 +402,13 @@ fn inline_field() {
     );
     assert_eq!(
         meta_inner_obj.all_of[1],
-        MetaSchemaRef::Inline(MetaSchema {
+        MetaSchemaRef::Inline(Box::new(MetaSchema {
             title: Some("Inner Obj"),
             default: Some(serde_json::json!({
                 "v": 100,
             })),
             ..MetaSchema::ANY
-        })
+        }))
     );
 
     let meta_inner_enum = meta.properties[1].1.unwrap_inline();
@@ -418,10 +418,34 @@ fn inline_field() {
     );
     assert_eq!(
         meta_inner_enum.all_of[1],
-        MetaSchemaRef::Inline(MetaSchema {
+        MetaSchemaRef::Inline(Box::new(MetaSchema {
             title: Some("Inner Enum"),
             default: Some(serde_json::json!("B")),
             ..MetaSchema::ANY
-        })
+        }))
     );
 }
+
+#[test]
+fn inline() {
+    #[derive(Object)]
+    #[oai(inline)]
+    struct Obj {
+        a: i32,
+    }
+
+    let schema_ref = Obj::schema_ref();
+    let meta: &MetaSchema = schema_ref.unwrap_inline();
+    assert_eq!(meta.properties[0].0, "a");
+
+    #[derive(Object)]
+    #[oai(inline)]
+    struct ObjGeneric<T: ParseFromJSON + ToJSON> {
+        a: T,
+    }
+
+    let schema_ref = ObjGeneric::<String>::schema_ref();
+    let meta: &MetaSchema = schema_ref.unwrap_inline();
+    assert_eq!(meta.properties[0].0, "a");
+    assert_eq!(meta.properties[0].1.unwrap_inline().ty, "string");
+}
